@@ -200,8 +200,10 @@ impl Config {
             }
             Arg::Long("sortby") => self.sort_by = ConfigEnum::from_str(argkey, value?)?,
             Arg::Long("searchby") => self.search_by = ConfigEnum::from_str(argkey, value?)?,
+            Arg::Long("limit") => self.limit = value?.parse()?,
             Arg::Long("news") | Arg::Short('w') => self.news += 1,
             Arg::Long("stats") | Arg::Short('s') => self.stats = true,
+            Arg::Long("order") | Arg::Short('o') => self.order = true,
             Arg::Long("removemake") => {
                 self.remove_make = YesNoAsk::Yes.default_or(argkey, value.ok())?
             }
@@ -235,6 +237,8 @@ impl Config {
             Arg::Long("nopgpfetch") => self.pgp_fetch = false,
             Arg::Long("useask") => self.use_ask = true,
             Arg::Long("nouseask") => self.use_ask = false,
+            Arg::Long("savechanges") => self.save_changes = true,
+            Arg::Long("nosavechanges") => self.save_changes = false,
             Arg::Long("combinedupgrade") => self.combined_upgrade = true,
             Arg::Long("nocombinedupgrade") => self.combined_upgrade = false,
             Arg::Long("batchinstall") => self.batch_install = true,
@@ -364,6 +368,7 @@ fn takes_value(arg: Arg) -> TakesValue {
         Arg::Long("completioninterval") => TakesValue::Required,
         Arg::Long("sortby") => TakesValue::Required,
         Arg::Long("searchby") => TakesValue::Required,
+        Arg::Long("limit") => TakesValue::Required,
         Arg::Long("removemake") => TakesValue::Optional,
         Arg::Long("redownload") => TakesValue::Optional,
         Arg::Long("rebuild") => TakesValue::Optional,
