@@ -8,7 +8,7 @@ use std::env::consts::ARCH;
 use std::env::{remove_var, set_var, var};
 use std::fmt;
 use std::fs::File;
-use std::io::{stdin, BufRead};
+use std::io::{stdin, stdout, BufRead};
 use std::path::{Path, PathBuf};
 
 use alpm::{
@@ -17,10 +17,9 @@ use alpm::{
 use ansi_term::Color::{Blue, Cyan, Green, Purple, Red, Yellow};
 use ansi_term::Style;
 use anyhow::{anyhow, bail, ensure, Context, Error, Result};
-use atty::Stream::Stdout;
 use cini::{Callback, CallbackKind, Ini};
 use globset::{Glob, GlobSet, GlobSetBuilder};
-use nix::unistd::dup2;
+use nix::unistd::{dup2, isatty};
 use std::os::unix::io::AsRawFd;
 use tr::tr;
 use url::Url;
@@ -100,7 +99,7 @@ pub struct Colors {
 impl From<&str> for Colors {
     fn from(s: &str) -> Self {
         match s {
-            "auto" if atty::is(Stdout) => Colors::new(),
+            "auto" if isatty(stdout().as_raw_fd()).unwrap_or(false) => Colors::new(),
             "always" => Colors::new(),
             _ => Colors::default(),
         }
@@ -349,6 +348,7 @@ pub struct Config {
 
     pub news: u32,
     pub stats: bool,
+    pub order: bool,
     pub gendb: bool,
 
     #[default(YesNoAll::No)]
@@ -361,6 +361,7 @@ pub struct Config {
     pub sort_by: SortBy,
     #[default(raur::SearchBy::NameDesc)]
     pub search_by: raur::SearchBy,
+    pub limit: usize,
     #[default(SortMode::TopDown)]
     pub sort_mode: SortMode,
     #[default(Mode::Any)]
@@ -383,6 +384,7 @@ pub struct Config {
     pub combined_upgrade: bool,
     pub batch_install: bool,
     pub use_ask: bool,
+    pub save_changes: bool,
     pub clean: usize,
     pub complete: bool,
     pub print: bool,
@@ -391,6 +393,8 @@ pub struct Config {
     pub sign: Sign,
     pub sign_db: Sign,
 
+    pub pre_build_command: Option<String>,
+
     #[default = "makepkg"]
     pub makepkg_bin: String,
     #[default = "pacman"]
@@ -808,6 +812,7 @@ impl Config {
             "SudoFlags" => self.sudo_flags.extend(split),
             "BatFlags" => self.bat_flags.extend(split),
             "FileManagerFlags" => self.fm_flags.extend(split),
+            "PreBuildCommand" => self.pre_build_command = Some(value),
             _ => eprintln!(
                 "{}",
                 tr!("error: unknown option '{}' in section [bin]", key)
@@ -841,19 +846,8 @@ impl Config {
             "CombinedUpgrade" => self.combined_upgrade = true,
             "BatchInstall" => self.batch_install = true,
             "UseAsk" => self.use_ask = true,
+            "SaveChanges" => self.save_changes = true,
             "NewsOnUpgrade" => self.news_on_upgrade = true,
-            "DevelSuffixes" => {
-                let value = value.ok_or_else(|| anyhow!(tr!("key can not be empty")))?;
-                let split = value.split_whitespace().map(|s| s.to_string());
-                self.devel_suffixes.extend(split);
-            }
-            "NoWarn" => {
-                let value = value.ok_or_else(|| anyhow!(tr!("key can not be empty")))?;
-                let split = value.split_whitespace().map(|s| s.to_string());
-                for word in split {
-                    self.no_warn_builder.add(Glob::new(&word)?);
-                }
-            }
             "InstallDebug" => self.install_debug = true,
             "Redownload" => self.redownload = YesNoAll::All.default_or(key, value)?,
             "Rebuild" => self.rebuild = YesNoAll::All.default_or(key, value)?,
@@ -902,8 +896,18 @@ impl Config {
             "RemoveMake" => self.remove_make = ConfigEnum::from_str(key, value?.as_str())?,
             "SortBy" => self.sort_by = ConfigEnum::from_str(key, value?.as_str())?,
             "SearchBy" => self.search_by = ConfigEnum::from_str(key, value?.as_str())?,
+            "Limit" => self.limit = value?.parse()?,
             "CompletionInterval" => self.completion_interval = value?.parse()?,
             "PacmanConf" => self.pacman_conf = Some(value?),
+            "DevelSuffixes" => {
+                self.devel_suffixes
+                    .extend(value?.split_whitespace().map(|s| s.to_string()));
+            }
+            "NoWarn" => {
+                for word in value?.split_whitespace() {
+                    self.no_warn_builder.add(Glob::new(word)?);
+                }
+            }
             _ => ok2 = false,
         };
 
