@@ -20,6 +20,7 @@ use std::fs::{read_dir, read_link, OpenOptions};
 use std::io::{stdin, stdout, BufRead, Read, Write};
 use std::path::Path;
 use std::process::{Command, Stdio};
+use std::sync::atomic::Ordering;
 
 use alpm::{Alpm, Depend, Version};
 use alpm_utils::depends::{satisfies_dep, satisfies_provide};
@@ -28,7 +29,7 @@ use ansi_term::Style;
 use anyhow::{bail, ensure, Context, Result};
 use args::Args;
 use aur_depends::{Actions, AurPackage, Base, Conflict, Flags, RepoPackage, Resolver};
-use nix::sys::signal::{signal, SigHandler, Signal};
+use log::debug;
 use raur::Cache;
 use srcinfo::Srcinfo;
 use tr::tr;
@@ -172,6 +173,7 @@ pub async fn build_pkgbuild(config: &mut Config) -> Result<i32> {
     );
 
     let actions = resolver.resolve_depends(&deps, &make_deps).await?;
+    debug!("{:#?}", actions);
     let mut build_info =
         prepare_build(config, HashMap::new(), &mut cache, actions, Some(&srcinfo)).await?;
 
@@ -270,7 +272,7 @@ pub async fn build_pkgbuild(config: &mut Config) -> Result<i32> {
     let paths = pkgdest.values().map(|s| s.as_str()).collect::<Vec<_>>();
     sign_pkg(config, &paths, build)?;
 
-    let db = config.alpm.syncdbs();
+    let db = repo::repo_aur_dbs(config).1;
     if let Some(default_repo) = default_repo {
         let pkgs = pkgdest.values().collect::<Vec<_>>();
         let r = if let Some(repo) = db
@@ -287,6 +289,7 @@ pub async fn build_pkgbuild(config: &mut Config) -> Result<i32> {
         let name = r.name().to_string();
         drop(repo);
         repo::add(config, path, &name, &pkgs)?;
+        drop(db);
         repo::refresh(config, &[name])?;
     }
 
@@ -451,6 +454,7 @@ pub async fn install(config: &mut Config, targets_str: &[String]) -> Result<i32>
     );
 
     let actions = resolver.resolve_targets(&targets).await?;
+    debug!("{:#?}", actions);
     let repo_targs = actions
         .install
         .iter()
@@ -547,6 +551,24 @@ async fn prepare_build(
     let bases = actions.iter_build_pkgs().map(|p| p.pkg.clone()).collect();
     let srcinfos = download_pkgbuilds(config, &bases).await?;
 
+    if let Some(ref cmd) = config.pre_build_command {
+        let args = ["-c", cmd.as_str()];
+
+        for base in &bases.bases {
+            let dir = config.fetch.clone_dir.join(base.package_base());
+            std::env::set_var("PKGBASE", base.package_base());
+            std::env::set_var("VERSION", base.version());
+            exec::command("sh", &dir, &args)?;
+        }
+
+        std::env::remove_var("PKGBASE");
+        std::env::remove_var("VERSION");
+
+        /*if srcinfo.is_some() {
+            exec::command(&cmd, ".", &args)?;
+        }*/
+    }
+
     if !config.skip_review {
         let ret = review(config, &actions)?;
         if ret != 0 {
@@ -713,7 +735,7 @@ async fn download_pkgbuilds<'a>(
                 vacant.insert(srcinfo);
             }
         } else {
-            bail!(tr!("could not find .SRINFO for '{}'", base.package_base()));
+            bail!(tr!("could not find .SRCINFO for '{}'", base.package_base()));
         }
     }
     Ok(srcinfos)
@@ -734,6 +756,10 @@ fn review<'a>(config: &Config, actions: &Actions<'a>) -> Result<i32> {
             if !ask(config, &tr!("Proceed with installation?"), true) {
                 return Ok(1);
             }
+
+            if config.save_changes {
+                config.fetch.commit(&pkgs, "paru save changes")?;
+            }
         } else {
             let unseen = config.fetch.unseen(&pkgs)?;
             let has_diff = config.fetch.has_diff(&unseen)?;
@@ -748,7 +774,7 @@ fn review<'a>(config: &Config, actions: &Actions<'a>) -> Result<i32> {
                     .or_else(|| var("PAGER").ok())
                     .unwrap_or_else(|| "less".to_string());
 
-                unsafe { signal(Signal::SIGPIPE, SigHandler::SigIgn).unwrap() };
+                exec::RAISE_SIGPIPE.store(false, Ordering::Relaxed);
                 let mut command = Command::new("sh");
 
                 if std::env::var("LESS").is_err() {
@@ -824,7 +850,7 @@ fn review<'a>(config: &Config, actions: &Actions<'a>) -> Result<i32> {
                                             "{} {} {}",
                                             tr!("failed to run:"),
                                             config.bat_bin,
-                                            file.path().display().to_string()
+                                            file.path().display()
                                         )
                                     })?;
                                 let _ = stdin.write_all(&output.stdout);
@@ -861,7 +887,7 @@ fn review<'a>(config: &Config, actions: &Actions<'a>) -> Result<i32> {
                 command
                     .wait()
                     .with_context(|| format!("{} {}", tr!("failed to run:"), pager))?;
-                unsafe { signal(Signal::SIGPIPE, SigHandler::SigDfl).unwrap() };
+                exec::RAISE_SIGPIPE.store(true, Ordering::Relaxed);
 
                 if !ask(config, &tr!("Proceed with installation?"), true) {
                     return Ok(1);
@@ -1162,19 +1188,6 @@ fn print_install(config: &Config, actions: &Actions) {
     println!();
 }
 
-/*fn download_pkgbuild_sources(config: &Config, build: &[aur_depends::Base]) -> Result<()> {
-    for base in build {
-        let pkg = base.package_base();
-        let dir = config.build_dir.join(pkg);
-
-        exec::makepkg(config, &dir, &["--verifysource", "-Ccf"])?
-            .success()
-            .with_context(|| format!("failed to download sources for '{}'", base))?;
-    }
-
-    Ok(())
-}*/
-
 fn do_install(
     config: &Config,
     deps: &mut Vec<&str>,
@@ -1382,28 +1395,21 @@ fn build_install_pkgbuild<'a>(
     let c = config.color;
     let mut debug_paths = HashMap::new();
     let dir = config.build_dir.join(base.package_base());
+    let db = config.alpm.localdb().pkgs();
 
-    let mut satisfied = false;
-
-    if !config.chroot && config.batch_install {
-        for pkg in &base.pkgs {
-            let mut deps = pkg
-                .pkg
-                .depends
-                .iter()
-                .chain(&pkg.pkg.make_depends)
-                .chain(&pkg.pkg.check_depends);
-
-            satisfied = deps.all(|dep| {
-                config
-                    .alpm
-                    .localdb()
-                    .pkgs()
-                    .find_satisfier(dep.as_str())
-                    .is_some()
+    let satisfied = !config.chroot
+        && config.batch_install
+        && base
+            .pkgs
+            .iter()
+            .flat_map(|pkg| {
+                pkg.pkg
+                    .depends
+                    .iter()
+                    .chain(&pkg.pkg.make_depends)
+                    .chain(&pkg.pkg.check_depends)
             })
-        }
-    }
+            .all(|dep| db.find_satisfier(dep.as_str()).is_some());
 
     if !config.chroot && !satisfied {
         do_install(config, deps, exp, install_queue, *conflict, devel_info)?;
@@ -1522,6 +1528,8 @@ fn build_install_pkgbuild<'a>(
             devel_info
                 .info
                 .insert(base.package_base().to_string(), info);
+        } else {
+            devel_info.info.remove(base.package_base());
         }
         if config.devel {
             save_devel_info(config, devel_info)?;
@@ -1565,6 +1573,8 @@ fn build_install_pkgbuild<'a>(
             devel_info
                 .info
                 .insert(base.package_base().to_string(), info);
+        } else {
+            devel_info.info.remove(base.package_base());
         }
     }
 
@@ -1609,7 +1619,7 @@ fn chroot_install(config: &Config, bi: &BuildInfo, repo_targs: &[String]) -> Res
             for _ in 0..config.args.count("y", "refresh") {
                 args.arg("y");
             }
-            for _ in 0..config.args.count("u", "susupgrade") {
+            for _ in 0..config.args.count("u", "sysupgrade") {
                 args.arg("u");
             }
         }
@@ -1699,7 +1709,7 @@ fn parse_package_list(config: &Config, dir: &Path) -> Result<(HashMap<String, St
     Ok((pkgdests, version))
 }
 
-fn flags(config: &mut Config) -> aur_depends::Flags {
+pub fn flags(config: &mut Config) -> aur_depends::Flags {
     let mut flags = Flags::new();
 
     if config.args.has_arg("needed", "needed") {
